summaryrefslogtreecommitdiffstats
path: root/kbabel/catalogmanager/catmanlistitem.h
diff options
context:
space:
mode:
Diffstat (limited to 'kbabel/catalogmanager/catmanlistitem.h')
-rw-r--r--kbabel/catalogmanager/catmanlistitem.h30
1 files changed, 15 insertions, 15 deletions
diff --git a/kbabel/catalogmanager/catmanlistitem.h b/kbabel/catalogmanager/catmanlistitem.h
index b156c034..a21db4f0 100644
--- a/kbabel/catalogmanager/catmanlistitem.h
+++ b/kbabel/catalogmanager/catmanlistitem.h
@@ -21,11 +21,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -54,25 +54,25 @@ namespace KBabel
class PoInfo;
}
-class CatManListItem : public QListViewItem
+class CatManListItem : public TQListViewItem
{
public:
/** the type of this item */
enum Type{File,Dir};
- CatManListItem(CatalogManagerView *view, TQListViewItem* parent,TQString fullPath
+ CatManListItem(CatalogManagerView *view, TQListViewItem* tqparent,TQString fullPath
,TQString fullPotPath,TQString package);
/** creates the toplevel root item with package name "/" */
- CatManListItem(CatalogManagerView *view, TQListView* parent,TQString fullPath, TQString fullPotPath);
+ CatManListItem(CatalogManagerView *view, TQListView* tqparent,TQString fullPath, TQString fullPotPath);
/**
* returns the package names (including relative path) of the
- * children of this item
+ * tqchildren of this item
*/
TQStringList contentsList(bool onlyFiles=false) const;
/**
- * returns the package names of all children of this item
+ * returns the package names of all tqchildren of this item
* (including all subdirectries)
* @param onlyFiles flag, if only the names of files should be returned
* @see CatManListItem::contentsList
@@ -80,7 +80,7 @@ public:
TQStringList allChildrenList(bool onlyFiles=false) const;
/**
- * returns the relative file names of all children of this item
+ * returns the relative file names of all tqchildren of this item
* (including all subdirectries)
* @param onlyFiles flag, if only the names of files should be returned
* @param emptyDirs flag, if the empty dirs (dirs without PO files in them) should be returned
@@ -94,7 +94,7 @@ public:
/**
* checks if the file on the disc has changed,
* reads information about the file and displays it
* @param noParents flag, if the update has to include the parent
* of the item, if the status has changed. Since at the first build of
* the tree, the status of every item changes, this is not useful then.
*/
@@ -119,7 +119,7 @@ public:
/** returns the package name (inlcuding relative path to base-directory) */
TQString package(bool rootSlash=true) const;
- /** returns the relative path of a dir or TQString::null if not a dir. */
+ /** returns the relative path of a dir or TQString() if not a dir. */
TQString packageDir( ) const;
/** returns the package name (without path) */
@@ -172,7 +172,7 @@ public:
TQStringList &wordList() { return _wordList; }
bool wordsUpdated() { return _wordListUpdated; }
/** These are not in Qt, so we need to implement it ourselves*/
TQListViewItem *previousSibling();
TQListViewItem *lastChild();
@@ -183,8 +183,8 @@ private:
* @param showPoInfo if true, reads information about the
* file using @ref Catalog::info
* ( slow for big files )
- * @param includeChildren flag, if possible children should be updated,too
- * @param noParents flag, if parents should be updated, when state
+ * @param includeChildren flag, if possible tqchildren should be updated,too
+ * @param noParents flag, if tqparents should be updated, when state
* of the item has changed
*/
void update(bool showPoInfo=true,bool includeChildren=false
@@ -227,7 +227,7 @@ private:
/** a list of errors found by validation tool*/
TQValueList<IgnoreItem> _errors;
/** parent view for this item, used for stopping the activity */
CatalogManagerView *_view;
/** index of words, but it does not contain any useful information as values */
@@ -94,7 +94,7 @@ public:
* checks if the file on the disc has changed,
* reads information about the file and displays it
- * @param noParents flag, if the update has to include the parent
+ * @param noParents flag, if the update has to include the tqparent
* of the item, if the status has changed. Since at the first build of
* the tree, the status of every item changes, this is not useful then.
@@ -172,7 +172,7 @@ public:
TQStringList &wordList() { return _wordList; }
bool wordsUpdated() { return _wordListUpdated; }
- /** These are not in Qt, so we need to implement it ourselves*/
+ /** These are not in TQt, so we need to implement it ourselves*/
TQListViewItem *previousSibling();
TQListViewItem *lastChild();
@@ -227,7 +227,7 @@ private:
/** a list of errors found by validation tool*/
TQValueList<IgnoreItem> _errors;
- /** parent view for this item, used for stopping the activity */
+ /** tqparent view for this item, used for stopping the activity */
CatalogManagerView *_view;
/** index of words, but it does not contain any useful information as values */